from setuptools import setup

setup(
        name="big_letters",
        version="0.0.1",
        author="Uwe Schmitt",
        description="prints text in big letters in your terminal",
        license="BSD",
        packages=["big_letters"]
        )
